function [tlon,tlat,sst,sstdev,cnt,status] = get_sst (latlim,lonlim,trange, ...
                                           tmpfile,sclfile,grdfile,xpndbd);
%
% function [tlon,tlat,sst,sstdev,cnt,status] = get_sst (latlim,lonlim, ...
%                                                   trange,tmpfile,sclfile, ...
%                                                       grdfile,xpndbd);
%
% This function reads the data necessary to convert a satellite image to a
% MODS file.
%
% ------
% Input:
% ------
%
%    LATLIM....Range of latitudes in image.
%    LONLIM....Range of longitudes in image.
%    TRANGE....Range of temperatures in color bar.
%    TMPFILE...Name of file with SST image.
%    SCLFILE...Name of file with SST color bar image.
%    GRDFILE...Name of Grids netCDF file.
%    XPNDBD....Expand Bad values flag.  [0] do not expand (default)
%              [1] make neighbors of bad values bad
%
% -------
% Output:
% -------
%
%    TLON......Vector of image longitudes.
%    TLAT......Vector im image latitudes.
%    SST.......Sea Surface Temperature matrix.
%    SSTDEV....Sea Surface Temperature Standard Deviation matrix.
%    CNT.......Number of values per gridded point.
%    STATUS...Exit status.  [0] no error  [other] error

%-------------------------------------------------------------------------------
% Set defaults.
%-------------------------------------------------------------------------------

if (nargin<6)
   xpndbd = 0;
end;

if ((xpndbd<0) | (xpndbd>3))
   xpndbd = 0;
end;

tlon = [];
tlat = [];
sst  = [];

%-------------------------------------------------------------------------------
% Get color scale.
%-------------------------------------------------------------------------------

%-------------------------------------
%--- Read temperature scale image. ---
%-------------------------------------

[red,green,blue,status] = read_ppm (sclfile);

if (status~=0)
   disp (' ');
   disp ('***Error:  GET_SST - unable to read temperature scale file:');
   disp (['           ',setstr(34),sclfile,setstr(34)]);
   return;
end;

%-----------------------------------------
%--- Extract temperature scale vector. ---
%-----------------------------------------

[ny nx] = size(blue);

imid = round((1+nx)/2);
jmid = round((1+ny)/2);

if ( abs(diff(blue(jmid,[1 nx]))) > abs(diff(blue([1 ny],imid))) )
   rscl = red(jmid,:);
   gscl = green(jmid,:);
   bscl = blue(jmid,:);
 else
   rscl = red(:,imid);
   gscl = green(:,imid);
   bscl = blue(:,imid);
end;

nsc = 1;

while (nsc < length(rscl))
   indwk = (nsc+1):length(rscl);
   indrm = find ( (rscl(indwk)==rscl(nsc)) &  (gscl(indwk)==gscl(nsc)) & ...
                  (bscl(indwk)==bscl(nsc)) );
   if ~isempty(indrm)
      rscl(indwk(indrm)) = [];
      gscl(indwk(indrm)) = [];
      bscl(indwk(indrm)) = [];
   end;

   nsc = nsc + 1;

end;

dt = diff(trange)/(length(rscl)-1);
tscl = trange(1):dt:trange(2);

%-------------------------------------------------------------------------------
% Get SST.
%-------------------------------------------------------------------------------

%-------------------------------------
%--- Read temperature scale image. ---
%-------------------------------------

[red,green,blue,status] = read_ppm (tmpfile);

if (status~=0)
   disp (' ');
   disp ('***Error:  GET_SST - unable to read sea surface temperature file:');
   disp (['           ',setstr(34),tmpfile,setstr(34)]);
   return;
end;

%----------------------------
%--- Construct Positions. ---
%----------------------------

[ny nx] = size(red);

dx = diff(lonlim)./(nx-1);
tlonfull = lonlim(1):dx:lonlim(2);

dy = diff(latlim)./(ny-1);
tlatfull = latlim(1):dy:latlim(2);

%----------------------------
%--- Construct SST field. ---
%----------------------------

sstfull = NaN.*red;

for n = 1:length(rscl)

   ind = find ( (red==rscl(n)) & (green==gscl(n)) & (blue==bscl(n)) );
   if ~isempty(ind)
      sstfull(ind) = tscl(n).*ones(size(ind));
   end;

end;

%------------------------
%--- Thin & clean SST ---
%------------------------

if (xpndbd>1),
   msk = ones(size(sstfull));
   ind = find(isnan(sstfull));
   msk(ind) = 0;
   n   = [2:ny ny];
   s   = [1 1:(ny-1)];
   e   = [2:nx nx];
   w   = [1 1:(nx-1)];
   msk = msk(n,w).*msk(n,:).*msk(n,e).* ...
         msk(:,w).*msk     .*msk(:,e).* ...
         msk(s,w).*msk(s,:).*msk(s,e);
   ind = find (msk==0);
   sstfull(ind) = NaN;
end;

if (xpndbd==3),
   ind      = find (~isnan(sstfull));
   mnsst    = mean(sstfull(ind));
   devsst   = abs(sstfull-mnsst);
   stdsst   = sqrt(mean(devsst(ind).*devsst(ind)).*length(ind)./ ...
                                                   (length(ind)-1));
   ind      = find (~isnan(devsst) & (devsst>3*stdsst));
   sstfull(ind) = NaN;
end;

%indx = 1:4:nx;
%indy = 1:4:ny;

%tlonfull = tlonfull(indx);
%tlatfull = tlatfull(indy);

%wk = sstfull(indy,indx);
%msk = ones(size(wk));
%ind = find(isnan(wk));
%msk(ind) = 0;

%if (xpndbd==1),
%   [my mx] = size(msk);
%   n   = [2:my my];
%   s   = [1 1:(my-1)];
%   e   = [2:mx mx];
%   w   = [1 1:(mx-1)];
%   msk = msk(n,w).*msk(n,:).*msk(n,e).* ...
%         msk(:,w).*msk     .*msk(:,e).* ...
%         msk(s,w).*msk(s,:).*msk(s,e);
%end;


%sstfull = flipud ( smooth_under3 (wk,msk) );
sstfull = flipud ( sstfull );

%-------------------------------------------------------------------------------
% Make diagnostic plots.
%-------------------------------------------------------------------------------

c(1:ny,1:nx,1) = red;
c(1:ny,1:nx,2) = green;
c(1:ny,1:nx,3) = blue;

image(c);

figure;
pcolor (tlonfull,tlatfull,sstfull);shading flat;colormap(jet);colorbar;

%-------------------------------------------------------------------------------
% Extract GRIDS data.
%-------------------------------------------------------------------------------

%--------------------------
%--- Read domain data+. ---
%--------------------------

[domdat,bath,landt,mcseg,mpseg,misle] = read_mask (grdfile);

clear bath landt mcseg mpseg misle;

%----------------------------
%--- Extract domain data. ---
%----------------------------

coord  = domdat( 1);
lonc   = domdat( 2);
latc   = domdat( 3);
theta  = domdat( 4);
im     = domdat( 5);
jm     = domdat( 6);
griddx = domdat( 7);
griddy = domdat( 8);
delx   = domdat( 9);
dely   = domdat(10);

%-------------------------------------------------------------------------------
% Grid SST data.
%-------------------------------------------------------------------------------

%-------------------------------------
%--- Get grid spacing, in degrees. ---
%-------------------------------------

if (coord~=0)
   dxdeg = griddx;
   dydeg = griddy;
 else
   m2km   = 1000;
   rearth = 6371.315*m2km;
   xc = (im+1)/2;
   yc = (jm+1)/2;
   [cenlon,cenlat] = xy2ll (xc,yc,coord,im,jm,griddx,griddy,lonc,latc, ...
                            delx,dely,theta);
   m2deg = 180/(pi*rearth);
   dydeg = griddy*m2deg;
   dxdeg = griddx*m2deg/cos(cenlat*pi/180);
   clear m2km rearth xc yc cenlon cenlat m2deg;
end;

clear coord lonc latc theta im jm griddx griddy delx dely;

%-------------------------------------
%--- Grid SST based on resolution. ---
%-------------------------------------

if ( (dx<dxdeg) & (dy<dydeg) )

   disp ('   --- Gridding SST from averaging');

   [tlon,tlat,sst,sstdev,cnt] = meansst (domdat,tlonfull,tlatfull,sstfull,dt);

 else

   disp ('   --- Gridding SST from nearest neighbor');

   [tlon,tlat,sst,sstdev,cnt] = nearsst (domdat,tlonfull,tlatfull,sstfull,dt);

end;
