function [heatflux,windflux,status] = read_flx2 (fluxname,ssttime);
%
% function [heatflux,windflux,status] = read_flx2 (fluxname,ssttime);
%
% This function read the surface heat flux at the given positions
% and times.
%
% ------
% Input:
% ------
%
%    FLUXNAME...Forcing netCDF file name.
%    SSTTIME....Times at which heat fluxes are desired.
%
% -------
% Output:
% -------
%
%    HEATFLUX...Surface heat flux for Neumann BC  (deg C cm^-1)
%    WINDFLUX...Wind stress for Eckman calculation.  (cm)
%    STATUS.....Exit Status.

%-------------------------------------------------------------------------------
% Initialize output.
%-------------------------------------------------------------------------------

heatflux = [];
windflux = [];

%-------------------------------------------------------------------------------
% Set Conversion factors.
%-------------------------------------------------------------------------------

s_std = 35.0;
t_std = 20.0;
p_std = 0.0;

rho0 = sw_dens0 (s_std,t_std);      % Density sea-water:               kg/(m^3)
Cp   = sw_cp (s_std,t_std,p_std);   % Heat capcity sea-water:          J/(kg C)
k_ht = 1e-7;                        % Kinematic thermal conductivity:  m^2/s
m2cm = 100.0;

crho0 = rho0/1000;                  % Density sea-water  gm/(cm^3)
omega = 2*pi*(366.25/365.25)/86400; % Earth angular rotation.

fnoc2neumann = 1/(rho0*Cp*k_ht*m2cm);

%-------------------------------------------------------------------------------
% Get surface forcing.
%-------------------------------------------------------------------------------

%--------------------------
%--- Open forcing file. ---
%--------------------------

ncid = mexcdf ('ncopen',fluxname,mexcdf('parameter','nc_nowrite'));

if (ncid<0),
   disp (' ');
   disp ('***Error:  READ_FLX - unable to open forcing file');
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   status = ncid;
   return;
end;

%--------------------------
%--- Get forcing times. ---
%--------------------------

name = 'shf_time';

[nftim,status] = get_dim (ncid,name);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read dimension ',setstr(34), ...
           name,setstr(34),' in forcing file']);
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

[flxtim,status] = get_var (ncid,name,0,nftim);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
           name,setstr(34),' in forcing file']);
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

%-------------------------------------
%--- Read bracketting time levels. ---
%-------------------------------------

name = 'tlon';

[nx,status] = get_dim (ncid,name);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read dimension ',setstr(34), ...
           name,setstr(34),' in forcing file']);
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

name = 'tlat';

[ny,status] = get_dim (ncid,name);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read dimension ',setstr(34), ...
           name,setstr(34),' in forcing file']);
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

st = max(find(flxtim<=ssttime)) - 1;

%-------------------------
%--- Read head fluxes. ---
%-------------------------

name = 'shflux';

[flx0,status] = get_var (ncid,name,[st 0 0],[1 ny nx]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

flx0 = fnoc2neumann.*flx0';

[flx1,status] = get_var (ncid,name,[(st+1) 0 0],[1 ny nx]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

flx1 = fnoc2neumann.*flx1';

%---------------------------
%--- Read wind stresses. ---
%---------------------------

name = 'vgrid2';

[vlat,status] = get_var (ncid,name,[0 0 1],[ny nx 1]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

f0 = 2.*omega.*abs(sin(vlat'.*pi./180));

name = 'smflux';

[uflx,status] = get_var (ncid,name,[st 0 0 0],[1 ny nx 1]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

[vflx,status] = get_var (ncid,name,[st 0 0 1],[1 ny nx 1]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

wflx0 = sqrt(uflx.*uflx+vflx.*vflx)';
wflx0 = sqrt(wflx0./crho0)./f0;

[uflx,status] = get_var (ncid,name,[(st+1) 0 0 0],[1 ny nx 1]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

[vflx,status] = get_var (ncid,name,[(st+1) 0 0 1],[1 ny nx 1]);

if (status<0),
   disp (' ');
   disp (['***Error:  READ_FLX - unable to read variable ',setstr(34), ...
          name,setstr(34),' in forcing file']);
   disp (['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;

wflx1 = sqrt(uflx.*uflx+vflx.*vflx)';
wflx1 = sqrt(wflx1./crho0)./f0;

%---------------------------
%--- Interpolate fluxes. ---
%---------------------------

wt0 = (flxtim(st+2)-ssttime)./(flxtim(st+2)-flxtim(st+1));

heatflux = flx0.*wt0 + flx1.*(1-wt0);
windflux = wflx0.*wt0 + wflx1.*(1-wt0);

%---------------------------
%--- Close forcing file. ---
%---------------------------

status = mexcdf ('ncclose',ncid);

if (status<0),
   disp (' ');
   disp ('***Error:  READ_FLX - unable to close forcing file');
   disp(['           ',setstr(34),fluxname,setstr(34)]);
   disp (' ');
   return;
end;
