function [lon,lat,temp,status] = read_sst (file);
%
% function [lon,lat,temp,status] = read_sst (file);
%
% This function reads the gridded SST data file
% produced at CMAST.
%
% ------
% Input:
% ------
%
%   FILE.....Name of input SST data file.
%
% -------
% Output:
% -------
%
%   LON......Longitudes for SST data.
%   LAT......Latitudes for SST data.
%   TEMP.....Gridded Sea Surface Temperature.
%   STATUS...Exit status.  [0] no error  [nonzero] error.

%-------------------------------------------------------------------------------
% Initialize output.
%-------------------------------------------------------------------------------

lon  = [];
lat  = [];
temp = [];

%-------------------------------------------------------------------------------
% Read data file.
%-------------------------------------------------------------------------------

%-----------------------
%--- Open data file. ---
%-----------------------

[fid,mess] = fopen (file,'r');

if (fid<0)
   disp (' ');
   disp ('***Error:  READ_SST - unable to open SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (['           ',setstr(34),mess,setstr(34)]);
   status = fid;
   return;
end;

%-----------------------
%--- Read data file. ---
%-----------------------

A = fscanf (fid,'%f',[5 inf]);

[mess,status] = ferror (fid);

if ( (status~=0) & ...
     (~strcmp(upper(mess),'AT END-OF-FILE.') | isempty(A)) )
   disp (' ');
   disp ('***Error:  READ_SST - unable to read SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (['           ',setstr(34),mess,setstr(34)]);
   return;
end;

%------------------------
%--- Close data file. ---
%------------------------

status = fclose (fid);

if (status<0)
   disp (' ');
   disp ('***Error:  READ_SST - unable to close SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   return;
end;

%-------------------------------------------------------------------------------
% Parse data array.
%-------------------------------------------------------------------------------

nx = max(A(1,:));
ny = max(A(2,:));

lon = reshape(A(3,:)',nx,ny)';
lat = reshape(A(4,:)',nx,ny)';
temp =  reshape(A(5,:)',nx,ny)';
