function [lon,lat,temp,tsdv,tcnt,status] = read_sst_flgg (file,fval,gfile);
%
% function [lon,lat,temp,tsdv,tcnt,status] = read_sst_flgg (file,fval,gfile);
%
% This function reads the gridded SST data file
% produced at CMAST.
%
% ------
% Input:
% ------
%
%   FILE.....Name of input SST data file.
%   FVAL.....Flag value.
%   GFILE....Name of Grids netCDF file.
%
% -------
% Output:
% -------
%
%   LON......Longitudes for SST data.
%   LAT......Latitudes for SST data.
%   TEMP.....Gridded Mean Sea Surface Temperature.
%   TSDV.....Gridded SST Standard Deviations.
%   TCNT.....Gridded number of SST values per mean value.
%   STATUS...Exit status.  [0] no error  [nonzero] error.

%-------------------------------------------------------------------------------
% Initialize output.
%-------------------------------------------------------------------------------

lon  = [];
lat  = [];
temp = [];
tsdv = [];
tcnt = [];

%-------------------------------------------------------------------------------
% Read data file.
%-------------------------------------------------------------------------------

%-----------------------
%--- Open data file. ---
%-----------------------

[fid,mess] = fopen (file,'r');

if (fid<0)
   disp (' ');
   disp ('***Error:  READ_SST_FLGG_FLGG - unable to open SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (['           ',setstr(34),mess,setstr(34)]);
   status = fid;
   return;
end;

%-----------------------
%--- Read data file. ---
%-----------------------

A = fscanf (fid,'%f',[5 inf]);

[mess,status] = ferror (fid);

if ( (status~=0) & ...
     (~strcmp(upper(mess),'AT END-OF-FILE.') | isempty(A)) )
   disp (' ');
   disp ('***Error:  READ_SST_FLGG - unable to read SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   disp (['           ',setstr(34),mess,setstr(34)]);
   return;
end;

%------------------------
%--- Close data file. ---
%------------------------

status = fclose (fid);

if (status<0)
   disp (' ');
   disp ('***Error:  READ_SST_FLGG - unable to close SST file:');
   disp (['           ',setstr(34),file,setstr(34)]);
   return;
end;

%-------------------------------------------------------------------------------
% Parse data array.
%-------------------------------------------------------------------------------

lon1D  = A(1,:);
lat1D  = A(2,:);
temp1D = A(3,:);
tsdv1D = A(4,:);
tcnt1D = A(5,:);

clear A;

%-------------------------------------------------------------------------------
% Extract GRIDS data.
%-------------------------------------------------------------------------------

%--------------------------
%--- Read domain data+. ---
%--------------------------

[domdat,bath,landt,mcseg,mpseg,misle] = read_mask (gfile);

clear bath landt mcseg mpseg misle;

%----------------------------
%--- Extract domain data. ---
%----------------------------

coord = domdat( 1);
lonc  = domdat( 2);
latc  = domdat( 3);
theta = domdat( 4);
im    = domdat( 5);
jm    = domdat( 6);
dx    = domdat( 7);
dy    = domdat( 8);
delx  = domdat( 9);
dely  = domdat(10);

%---------------------------------------
%--- Compare grid size to data size. ---
%---------------------------------------

if ((im*jm)~=length(lon1D)),
   disp (' ');
   disp ('***Error:  READ_SST_FLGG_FLGG - incompatible grids.');
   disp (['           number of data points:  ',num2str(length(lon1D))]);
   disp (['           number of grid points (im*jm):  ',num2str(im*j)]);
   disp (' ');
   status = -1;
   return;
end;

%-------------------------------------------------------------------------------
% Grid SST data.
%-------------------------------------------------------------------------------

%-----------------------------
%--- Create working space. ---
%-----------------------------

lon  = ones(jm,im);
lat  = ones(jm,im);
temp = ones(jm,im);
tsdv = ones(jm,im);
tcnt = ones(jm,im);

%--------------------------
%--- Determine mapping. ---
%--------------------------

[iind,jind]   = ll2xy (lon1D,lat1D,coord,im,jm,dx,dy,lonc,latc,delx,dely,theta);

iind = round(iind);
jind = round(jind);

ind = jind + (iind-1).*jm;

%----------------------
%--- Grid SST data. ---
%----------------------

lon(ind)  = lon1D;
lat(ind)  = lat1D;
temp(ind) = temp1D;
tsdv(ind) = tsdv1D;
tcnt(ind) = tcnt1D;

%-------------------------------------------------------------------------------
% Remove flagged values.
%-------------------------------------------------------------------------------

ind = find ( (abs(temp-fval)<sqrt(eps)) | (abs(tsdv-fval)<sqrt(eps)) | ...
             (abs(tcnt-fval)<sqrt(eps)) );

if ~isempty(ind)
   temp(ind) = NaN;
   tsdv(ind) = NaN;
   tcnt(ind) = NaN;
end;
