% sstppm2oa
%
% This script puts mapped SST data onto a HOPS OA(G)/FM netCDF file.

%-------------------------------------------------------------------------------
% Get run parameters.
%-------------------------------------------------------------------------------

infiledef = 'sstppm2oa.in';

infile = input (['Enter name for parameter input file [',infiledef,']: '],'s');

if isempty(infile)
   infile = infiledef;
end;

clear infiledef

[xpndbd,latlim,lonlim,trange,smthrep,combflg,ekfac,jdate,sstfile,sclfile, ...
                 grdfile,frcfile,oafile,status]  = sstppm2oa_inparm (infile);

if (status<0)
   disp (' ');
   disp ('***Error:  SSTPPM2OA - unable to read parameter input file:');
   disp (['           ',setstr(34),infile,setstr(34)]);
   return;
end;

clear infile status

%-------------------------------------------------------------------------------
% Set useful parameters.
%-------------------------------------------------------------------------------

cm2m       = 0.01;

%-------------------------------------------------------------------------------
% Read in data.
%-------------------------------------------------------------------------------

%----------------
%--- Get SST. ---
%----------------

ann_tic ('Getting SST data.');

[lon,lat,temp,tsdv,tcnt,status] = get_sst (latlim,lonlim,trange, ...
                                           sstfile,sclfile,grdfile,xpndbd);

hms_toc

if (status~=0),
   disp (' ');
   disp ('***Error:  SSTPPM2OA - unable to read SST file');
   disp(['           ',setstr(34),sstfile,setstr(34)]);
   disp (' ');
   return;
end;

clear status;

%---------------------------
%--- Get surface fluxes. ---
%---------------------------

[HeatFlux,WindStress,status] = read_flx2 (frcfile,jdate);

if (status<0),
   disp (' ');
   disp ('***Error:  SSTPPM2OA - unable to read forcing file');
   disp(['           ',setstr(34),frcfile,setstr(34)]);
   disp (' ');
   return;
end;

%-------------------------------------------------------------------------------
% Construct mixed layer depths.
%-------------------------------------------------------------------------------

zmld  = ekfac.*WindStress.*cm2m;

%-------------------------------------------------------------------------------
% Construct SST errors.
%-------------------------------------------------------------------------------

%--------------------------------------------------
%--- Scale Standard Deviations by SST variance. ---
%--------------------------------------------------

ind = find (~isnan(temp));

tvar = sum( (temp(ind)-mean(temp(ind))).^2 )./(length(ind)-1);

terr = tsdv.*tsdv./tvar;

%-------------------------------------------------
%--- Set single observations to maximum error. ---
%-------------------------------------------------

ind = find ( ~isnan(tcnt) & (tcnt>1) );
if ~isempty(ind)
   temx = max(terr(ind));
  else
   temx = 1;
end;

ind = find (~isnan(tcnt) & (tcnt<=1) );
terr(ind) = temx;

ind = find (isnan(terr));
terr(ind) = max([temx 1]);

%-------------------------------------------
%--- Smooth error field to avoid shocks. ---
%-------------------------------------------

msk = make_errbnd_msk (terr,smthrep);
terrsm = smooth_under_iw (terr,msk);

clear msk;

%-------------------------------------------------------------------------------
% Place SST into OA(G)/FM file.
%-------------------------------------------------------------------------------

if (combflg)
%   status = comb_oa (temp,terrsm,zmld,jdate,oafile);
   disp (' ');
   disp ('**********************************************');
   disp ('***    Combination option not yet coded.   ***');
   disp ('*** OA(G)/FM file will not be overwritten. ***');
   disp ('**********************************************');
   disp (' ');
 else
   status = rep_oa (temp,terrsm,zmld,jdate,oafile);
end;

if (status<0)
   disp (' ');
   disp ('***Error:  SSTPPM2OA - unable to place SST into OA(G)/FM file:');
   disp (['           ',setstr(34),oafile,setstr(34)]);
   return;
end;

clear oafile;

%-------------------------------------------------------------------------------
% Plot SST.
%-------------------------------------------------------------------------------

cstfile = '/home/haley/Oceanplot/Coast_data/gulf_cst.dat';
[clon,clat] = rcoastline (cstfile);
clear cstfile;

figure;
plot_fld (lon,lat,temp,[]);

title (['Sea Surface Temperature (^oC)  [', ...
        num2str(extrem(temp(find(~isnan(temp))))),']']);
h=suptitle(sstfile);
set(h,'Interpreter','None','FontName','Times','FontSize',12);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);

%-------------------------------------------------------------------------------
% Plot Error Field.
%-------------------------------------------------------------------------------

figure;
%plot_fld (lon,lat,terrsm,nice([0 1],4));
pcolor (lon,lat,terrsm);shading flat;colorbar;
set(gca,'FontName','Times','FontSize',14);

title (['NonDimensional Error  [', ...
        num2str(extrem(terrsm(find(~isnan(terrsm))))),']']);
h=suptitle(sstfile);
set(h,'Interpreter','None','FontName','Times','FontSize',12);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);

%-------------------------------------------------------------------------------
% Plot Mixed Layer Depth Field.
%-------------------------------------------------------------------------------

figure;
plot_fld (lon,lat,zmld,[]);

title (['Mixed Layer Depth  (m)  [',num2str(extrem(zmld(:))),']']);
h=suptitle(frcfile);
set(h,'Interpreter','None','FontName','Times','FontSize',12);
hold on;
h = fill_cst (clon,clat,[0.9 0.9 0.9],[0.5 0.5 0.5]);
